==> qtjambi-debuginfo-macos-5.15.18.jar: sources/QtJambiGui/QScrollPrepareEvent_shell.cpp <==
#include "QScrollPrepareEvent_shell.h"
#include <QtJambi/Cast>

void deleter_QScrollPrepareEvent(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QScrollPrepareEvent")
    QScrollPrepareEvent *_ptr = reinterpret_cast<QScrollPrepareEvent *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QScrollPrepareEvent_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QScrollPrepareEvent_shell) ); }

jmethodID QScrollPrepareEvent_shell::__shell_javaMethod(int pos) const { return QScrollPrepareEvent_shell::__shell()->javaMethod(typeid(QScrollPrepareEvent), pos); }

// emitting (writeShellConstructor)
QScrollPrepareEvent_shell::QScrollPrepareEvent_shell(const QPointF& startPos0)
    : QScrollPrepareEvent(startPos0)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QScrollPrepareEvent::QScrollPrepareEvent_shell(const QPointF& startPos0)", QScrollPrepareEvent_shell::__shell())
    QScrollPrepareEvent_shell::__shell()->constructed(typeid(QScrollPrepareEvent));
}

// emitting (writeShellDestructor)
QScrollPrepareEvent_shell::~QScrollPrepareEvent_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QScrollPrepareEvent::~QScrollPrepareEvent()", QScrollPrepareEvent_shell::__shell())
    QScrollPrepareEvent_shell::__shell()->destructed(typeid(QScrollPrepareEvent));
}

void QScrollPrepareEvent_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QScrollPrepareEvent_shell*>(ptr)->QScrollPrepareEvent_shell::__shell()->tryDeleteShell(typeid(QScrollPrepareEvent));
}

// emitting Virtual overrides (virtualFunctions)
// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
// emitting (writeConstructors)
// new QScrollPrepareEvent(QPointF)
void __qt_construct_QScrollPrepareEvent_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QScrollPrepareEvent(QPointF)")
    jobject startPos0 = __java_arguments[0].l;
    const QPointF& __qt_startPos0 = qtjambi_cast<const QPointF& >(__jni_env, startPos0);
    QScrollPrepareEvent *__qt_this = new(__qtjambi_ptr) QScrollPrepareEvent_shell(__qt_startPos0);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QScrollPrepareEvent_shell
void __qt_destruct_QScrollPrepareEvent(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QScrollPrepareEvent")
    reinterpret_cast<QScrollPrepareEvent_shell*>(ptr)->~QScrollPrepareEvent_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QScrollPrepareEvent::QScrollPrepareEvent(QPointF)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QScrollPrepareEvent_initialize_1native__Lio_qt_gui_QScrollPrepareEvent_2Lio_qt_core_QPointF_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject startPos0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QScrollPrepareEvent::QScrollPrepareEvent(QPointF)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = startPos0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QScrollPrepareEvent_0, sizeof(QScrollPrepareEvent_shell), typeid(QScrollPrepareEvent), true, &deleter_QScrollPrepareEvent, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QScrollPrepareEvent::contentPos()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QScrollPrepareEvent_contentPos_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QScrollPrepareEvent *__qt_this = QtJambiAPI::objectFromNativeId<QScrollPrepareEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QScrollPrepareEvent::contentPos()const", __qt_this)
        QPointF __qt_return_value = __qt_this->contentPos();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QScrollPrepareEvent::contentPosRange()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QScrollPrepareEvent_contentPosRange_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QScrollPrepareEvent *__qt_this = QtJambiAPI::objectFromNativeId<QScrollPrepareEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QScrollPrepareEvent::contentPosRange()const", __qt_this)
        QRectF __qt_return_value = __qt_this->contentPosRange();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QScrollPrepareEvent::setContentPos(QPointF)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QScrollPrepareEvent_setContentPos_1native_1cref_1QPointF__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID pos0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QScrollPrepareEvent *__qt_this = QtJambiAPI::objectFromNativeId<QScrollPrepareEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QScrollPrepareEvent::setContentPos(QPointF)", __qt_this)
        const QPointF& __qt_pos0 = QtJambiAPI::valueReferenceFromNativeId<QPointF>(pos0);
        __qt_this->setContentPos(__qt_pos0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QScrollPrepareEvent::setContentPosRange(QRectF)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QScrollPrepareEvent_setContentPosRange_1native_1cref_1QRectF__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID rect0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QScrollPrepareEvent *__qt_this = QtJambiAPI::objectFromNativeId<QScrollPrepareEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QScrollPrepareEvent::setContentPosRange(QRectF)", __qt_this)
        const QRectF& __qt_rect0 = QtJambiAPI::valueReferenceFromNativeId<QRectF>(rect0);
        __qt_this->setContentPosRange(__qt_rect0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QScrollPrepareEvent::setViewportSize(QSizeF)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QScrollPrepareEvent_setViewportSize_1native_1cref_1QSizeF__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID size0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QScrollPrepareEvent *__qt_this = QtJambiAPI::objectFromNativeId<QScrollPrepareEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QScrollPrepareEvent::setViewportSize(QSizeF)", __qt_this)
        const QSizeF& __qt_size0 = QtJambiAPI::valueReferenceFromNativeId<QSizeF>(size0);
        __qt_this->setViewportSize(__qt_size0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QScrollPrepareEvent::startPos()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QScrollPrepareEvent_startPos_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QScrollPrepareEvent *__qt_this = QtJambiAPI::objectFromNativeId<QScrollPrepareEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QScrollPrepareEvent::startPos()const", __qt_this)
        QPointF __qt_return_value = __qt_this->startPos();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QScrollPrepareEvent::viewportSize()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QScrollPrepareEvent_viewportSize_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QScrollPrepareEvent *__qt_this = QtJambiAPI::objectFromNativeId<QScrollPrepareEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QScrollPrepareEvent::viewportSize()const", __qt_this)
        QSizeF __qt_return_value = __qt_this->viewportSize();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QScrollPrepareEvent_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QScrollPrepareEvent *__qt_this = QtJambiAPI::objectFromNativeId<QScrollPrepareEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = QtJambiAPI::convertNativeToJavaOwnedObjectAsWrapper(__jni_env, new QScrollPrepareEvent(*__qt_this));
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QScrollPrepareEvent(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QScrollPrepareEvent>("QScrollPrepareEvent", "io/qt/gui/QScrollPrepareEvent");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QScrollPrepareEvent, {
        ConstructorInfo(&__qt_construct_QScrollPrepareEvent_0, "Lio/qt/core/QPointF;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QScrollPrepareEvent);
    registerSizeOfShell(typeId, sizeof(QScrollPrepareEvent_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QEvent, QScrollPrepareEvent>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-macos-5.15.19.jar: sources/QtJambiGui/QScrollPrepareEvent_shell.cpp <==
#include "QScrollPrepareEvent_shell.h"
#include <QtJambi/Cast>

void deleter_QScrollPrepareEvent(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QScrollPrepareEvent")
    QScrollPrepareEvent *_ptr = reinterpret_cast<QScrollPrepareEvent *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QScrollPrepareEvent_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QScrollPrepareEvent_shell) ); }

jmethodID QScrollPrepareEvent_shell::__shell_javaMethod(int pos) const { return QScrollPrepareEvent_shell::__shell()->javaMethod(typeid(QScrollPrepareEvent), pos); }

// emitting (writeShellConstructor)
QScrollPrepareEvent_shell::QScrollPrepareEvent_shell(const QPointF& startPos0)
    : QScrollPrepareEvent(startPos0)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QScrollPrepareEvent::QScrollPrepareEvent_shell(const QPointF& startPos0)", QScrollPrepareEvent_shell::__shell())
    QScrollPrepareEvent_shell::__shell()->constructed(typeid(QScrollPrepareEvent));
}

QScrollPrepareEvent_shell::QScrollPrepareEvent_shell(const QScrollPrepareEvent& other0)
    : QScrollPrepareEvent(other0)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QScrollPrepareEvent::QScrollPrepareEvent_shell(const QScrollPrepareEvent& other0)", QScrollPrepareEvent_shell::__shell())
    QScrollPrepareEvent_shell::__shell()->constructed(typeid(QScrollPrepareEvent));
}

// emitting (writeShellDestructor)
QScrollPrepareEvent_shell::~QScrollPrepareEvent_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QScrollPrepareEvent::~QScrollPrepareEvent()", QScrollPrepareEvent_shell::__shell())
    QScrollPrepareEvent_shell::__shell()->destructed(typeid(QScrollPrepareEvent));
}

void QScrollPrepareEvent_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QScrollPrepareEvent_shell*>(ptr)->QScrollPrepareEvent_shell::__shell()->tryDeleteShell(typeid(QScrollPrepareEvent));
}

// emitting Virtual overrides (virtualFunctions)
// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
// emitting (writeConstructors)
// new QScrollPrepareEvent(QPointF)
void __qt_construct_QScrollPrepareEvent_cref_QPointF(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QScrollPrepareEvent(QPointF)")
    jobject startPos0 = __java_arguments[0].l;
    const QPointF& __qt_startPos0 = qtjambi_cast<const QPointF& >(__jni_env, startPos0);
    QScrollPrepareEvent *__qt_this = new(__qtjambi_ptr) QScrollPrepareEvent_shell(__qt_startPos0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QScrollPrepareEvent::QScrollPrepareEvent(QPointF)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QScrollPrepareEvent_initialize_1native__Lio_qt_gui_QScrollPrepareEvent_2Lio_qt_core_QPointF_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject startPos0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QScrollPrepareEvent::QScrollPrepareEvent(QPointF)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = startPos0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QScrollPrepareEvent_cref_QPointF, sizeof(QScrollPrepareEvent_shell), typeid(QScrollPrepareEvent), true, &deleter_QScrollPrepareEvent, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QScrollPrepareEvent(QScrollPrepareEvent)
void __qt_construct_QScrollPrepareEvent_cref_QScrollPrepareEvent(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QScrollPrepareEvent(QScrollPrepareEvent)")
    jobject other0 = __java_arguments[0].l;
    const QScrollPrepareEvent& __qt_other0 = qtjambi_cast<const QScrollPrepareEvent& >(__jni_env, other0);
    QScrollPrepareEvent *__qt_this = new(__qtjambi_ptr) QScrollPrepareEvent_shell(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QScrollPrepareEvent::QScrollPrepareEvent(QScrollPrepareEvent)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QScrollPrepareEvent_initialize_1native__Lio_qt_gui_QScrollPrepareEvent_2Lio_qt_gui_QScrollPrepareEvent_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QScrollPrepareEvent::QScrollPrepareEvent(QScrollPrepareEvent)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QScrollPrepareEvent_cref_QScrollPrepareEvent, sizeof(QScrollPrepareEvent_shell), typeid(QScrollPrepareEvent), true, &deleter_QScrollPrepareEvent, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QScrollPrepareEvent_shell
void __qt_destruct_QScrollPrepareEvent(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QScrollPrepareEvent")
    reinterpret_cast<QScrollPrepareEvent_shell*>(ptr)->~QScrollPrepareEvent_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QScrollPrepareEvent::contentPos()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QScrollPrepareEvent_contentPos_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QScrollPrepareEvent *__qt_this = QtJambiAPI::objectFromNativeId<QScrollPrepareEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QScrollPrepareEvent::contentPos()const", __qt_this)
        QPointF __qt_return_value = __qt_this->contentPos();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QScrollPrepareEvent::contentPosRange()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QScrollPrepareEvent_contentPosRange_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QScrollPrepareEvent *__qt_this = QtJambiAPI::objectFromNativeId<QScrollPrepareEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QScrollPrepareEvent::contentPosRange()const", __qt_this)
        QRectF __qt_return_value = __qt_this->contentPosRange();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QScrollPrepareEvent::setContentPos(QPointF)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QScrollPrepareEvent_setContentPos_1native_1cref_1QPointF__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID pos0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QScrollPrepareEvent *__qt_this = QtJambiAPI::objectFromNativeId<QScrollPrepareEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QScrollPrepareEvent::setContentPos(QPointF)", __qt_this)
        const QPointF& __qt_pos0 = QtJambiAPI::valueReferenceFromNativeId<QPointF>(pos0);
        __qt_this->setContentPos(__qt_pos0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QScrollPrepareEvent::setContentPosRange(QRectF)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QScrollPrepareEvent_setContentPosRange_1native_1cref_1QRectF__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID rect0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QScrollPrepareEvent *__qt_this = QtJambiAPI::objectFromNativeId<QScrollPrepareEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QScrollPrepareEvent::setContentPosRange(QRectF)", __qt_this)
        const QRectF& __qt_rect0 = QtJambiAPI::valueReferenceFromNativeId<QRectF>(rect0);
        __qt_this->setContentPosRange(__qt_rect0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QScrollPrepareEvent::setViewportSize(QSizeF)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QScrollPrepareEvent_setViewportSize_1native_1cref_1QSizeF__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID size0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QScrollPrepareEvent *__qt_this = QtJambiAPI::objectFromNativeId<QScrollPrepareEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QScrollPrepareEvent::setViewportSize(QSizeF)", __qt_this)
        const QSizeF& __qt_size0 = QtJambiAPI::valueReferenceFromNativeId<QSizeF>(size0);
        __qt_this->setViewportSize(__qt_size0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QScrollPrepareEvent::startPos()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QScrollPrepareEvent_startPos_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QScrollPrepareEvent *__qt_this = QtJambiAPI::objectFromNativeId<QScrollPrepareEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QScrollPrepareEvent::startPos()const", __qt_this)
        QPointF __qt_return_value = __qt_this->startPos();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QScrollPrepareEvent::viewportSize()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QScrollPrepareEvent_viewportSize_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QScrollPrepareEvent *__qt_this = QtJambiAPI::objectFromNativeId<QScrollPrepareEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QScrollPrepareEvent::viewportSize()const", __qt_this)
        QSizeF __qt_return_value = __qt_this->viewportSize();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QScrollPrepareEvent_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QScrollPrepareEvent *__qt_this = QtJambiAPI::objectFromNativeId<QScrollPrepareEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = QtJambiAPI::convertNativeToJavaOwnedObjectAsWrapper(__jni_env, new QScrollPrepareEvent(*__qt_this));
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QScrollPrepareEvent(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QScrollPrepareEvent>("QScrollPrepareEvent", "io/qt/gui/QScrollPrepareEvent");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QScrollPrepareEvent, {
        ConstructorInfo(&__qt_construct_QScrollPrepareEvent_cref_QPointF, "Lio/qt/core/QPointF;")
       ,ConstructorInfo(&__qt_construct_QScrollPrepareEvent_cref_QScrollPrepareEvent, "Lio/qt/gui/QScrollPrepareEvent;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QScrollPrepareEvent);
    registerSizeOfShell(typeId, sizeof(QScrollPrepareEvent_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QEvent, QScrollPrepareEvent>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
